from setuptools import setup

setup(
    author='CryptoGu',
    author_email='kriptoairdrop9@gmail.com',
     name='gu-tea3',
    version='0.1',
    description='Simple project that makes a request to Agify API to guess age by name.',
    url='https://github.com/CryptoGu1/gu-tea3.git',
    project_urls={
        'Homepage': 'https://github.com/CryptoGu1/gu-tea3.git',
        'Source': 'https://github.com/CryptoGu1/gu-tea3.git',
        },
    py_modules=['hello_world_api1'],
     install_requires=[
        'requests>=2.20.0',
        "Gu-tea"
        "gu-tea2"
        
    ]
)